; This file is generated by the program tools/tools/validating-html-mirroring-from-dtd/laml-mirror-via-dtd.scm. Do not edit!

;;;; This an accurate, validating mirror of XHMTL1.0 (strict) on basic form. A basic form has a rigid syntactic composition:<font size = 3><pre>   (xhtml1:tag contents . attributes)</pre></font><p>The type of contents must be a list of content elements (strings, sub-elements, space suppress, and lists of these) and the attributes must be alternating symbol attribute names and string attribute values.<p>Here is a concrete example: <font size = 3><pre>   (xhtml1:a (list "AAU CS") 'href "www.cs.auc.dk")</pre></font>In general we recommend that you use the HTML mirror on its <a href = "surface.html">surface form</a>. Use the basic form if you need to write more efficient programs (such as CGI programs) which emit HTML, represented as internal ASTs. The function <kbd>render</kbd> converts an AST to a string. The function <kbd>write-html</kbd> from the <kbd>laml.scm</kbd> file is helpful when rendering, linearizing and writing an AST to a text file. <p>Each function in this file mirrors and generates an HTML element instance. If the boolean variable <kbd>check-html-attributes?</kbd> is true the functions check the attributes of the tag against the attribute definitions in the document type definition. If the boolean variable <kbd>validate-html?</kbd> is true the mirror functions perform a <b>full HTML validity check.</b> <p>CSS inline style attributes can be given side by side with the HTML attributes. A CSS attribute is prefixed with 'css:'. Here is an example: <font size = 3><pre>   (xhtml1:a "AAU CS" 'href "www.cs.auc.dk" 'css:text-decoration "none" 'css:background-color "yellow")</pre></font><p>This library requires the general library.<p>See also the <a href = "surface.html">surface form library</a> of the mirror.

(define xml-syntax? #t)

;;; The XML and document type declaration.
;;; This section contains <kbd>document-type-declaration</kbd>, that returns the appropriate
;;; document type declaration of this mirror. In addition, it contains the XML declaration and
;;; a redefintion of standard-prolog from laml.scm.

;; Return a document type declaration of this mirror.
(define (document-type-declaration)
  "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\"
    \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">")

;; Return the xml declaration
(define (xml-declaration)
  "<?xml version=\"1.0\" encoding=\"iso-8859-1\"?>")

;; Return the standard prolog of an XHTML document, properly extended with the xml declaration
;; relative to the standard-prolog of laml.scm.
(define (standard-prolog)
 (string-append
  (xml-declaration) (as-string #\newline)
  (document-type-declaration)
  (if (not (empty-string? (document-type-declaration))) (as-string #\newline) "")
  (copyright-clause)
  (if (not (empty-string? (copyright-clause))) (as-string #\newline) "")))


;;; Configuration part.
;;; The variables and functions in this part controls the checking, validation, and error reporting of the HTML mirror functions.

;; A boolean variable which controls the checking of tag attributes.
;; If true, check the tag (element) attributes against the attributes as defined in the DTD file.
;; The default value is true.
(define check-html-attributes? #t)

;; A boolean variable that controls the HTML validation.
;; If true, do validate the generated HTML string against the DTD (the grammar of HTML).
;; The default value is true.
(define validate-html? #t)

;; A boolean variable that controls extra HTML validation.
;; In XHTML, certain document analomies cannot be prevented by the DTD.
;; Some elements have element prohibitions beyond those specified by the DTD.
;; LAML can check these additional prohibitions if this variable is true (#t).
(define check-element-prohibitions? #t)

;; A boolean variable that controls whether CDATA (Character data) are transformed
;; through the HTML character transformation table. The default value is true.
;; .reference "Character transformation table" "table" "../../../man/laml.html#html-char-transformation-table"
(define transliterate-character-data? #t)

;; A list of elements for which content data - CDATA - is never transformed.
;; As an example, it will often cause problems if scripts are being modified by means of transliterations using
;; the HTML character transformation table.
;; A list of strings.
;; Defaults to (list "script" "style").
;; You can redefine it after the document style has been loaded.
(define non-transliteration-elements (list "script" "style"))

;; How many characters of the HTML validation error messages to be presented.
(define error-truncation-length 150)

; --------------------------------------------------------------------------------------------------------------------------------
; Tag functions. Redefined temporarily to make ASTs.

; Return a balanced html tag of both start and end tag, based on the parameters name (tag name) contents and attributes.
; The attributes is supposed to be a property list of symbol string pairs.
(define (internal-ast-node name contents attributes)    ; former itag
 (make-ast name contents attributes 'double))


; Return a single tag of name with attributes.
; The attributes is supposed to be a property list of symbol string pairs.
(define (terminal-ast-node name attributes)  ; former itag1
 (make-ast name '() attributes 'single))

; Individual tag functions, which could be used above if we wanted to:

; Return an HTML start tag.
; The parameter kind is a string or a symbol.
; attributes is a lisp property list of key-symbol value pairs, including the possibility of CSS attributes on the form css:attr-name.
(define (start-tag kind . attributes)
  (if (null? attributes) 
      (string-append "<" (as-string kind) ">")
      (let* ((attributes (linearize-attributes attributes))
              (html-attributes (car attributes))
              (css-attributes (cdr attributes)))
         (string-append "<" (as-string kind) " " html-attributes  
                        (if (empty-string? css-attributes) "" (string-append " style = " (string-it css-attributes)))
                        " >"))))


; Retun an HTML end tag.
; The parameter kind is a string or a symbol.
(define (end-tag kind)
  (string-append "</" (as-string kind) ">"))

; --------------------------------------------------------------------------------------------------------------------------------
; Attribute linearization. 

; convert the Lisp property list attr-list to a string conforming
; to the rules of an html attribute list
; (define (linearize-attributes attr-list)
;   (string-append  (linearize-attributes-1 (reverse attr-list) "" (length attr-list))))
; 
; (define (linearize-attributes-1 attr-list res-string lgt)
;   (cond ((= lgt  0 ) res-string)
;         ((>= lgt 2) (linearize-attributes-1 
;                        (cddr attr-list)
;                        (string-append (linearize-attribute-pair (car attr-list) (cadr attr-list)) " " res-string)
;                        (- lgt 2)))
;         ((< lgt 2) (error "Linearize-attributes-1: Called with an odd length attribute list. Not a Lisp property list"))))
; 
; (define (linearize-attribute-pair val attr)
;   (string-append (as-string attr) " = " (string-it (as-string val))))

; Return a pair of strings: The head is the string represeting html attributes.
; The tail is the string representing the css attributes (to go into an HTML style attribute).
(define (linearize-attributes attr-list)
 (let ((lgt (length attr-list)))
  ; catch a typical error here: non-symbol key, probably old-fashioned calling convention from html-v1.
  (if (and (>= lgt 1) (not (symbol? (car attr-list))))
      (error (string-append "linearize-attributes: Non-symbol key encountered: " (as-string (car attr-list)) " in attribute list " (as-string attr-list) ". Maybe conversion problem from html-v1.")))
  (linearize-attributes-1 (reverse attr-list) "" "" lgt attr-list)))

; Internal helping operation to linearize-attributes. The parameter whole-attr-list is for error messaging purposes
(define (linearize-attributes-1 attr-list html-attr-string css-attr-string lgt whole-attr-list)
  (cond ((= lgt  0 ) (cons (strip-trailing-characters (list #\space) html-attr-string) css-attr-string))
        ((>= lgt 2) (let* ((val (car attr-list))   ; val and key are reversed at this time
                           (key (cadr attr-list))
                           (css-key (css-key? key))
                         )
                     (cond (css-key                  ; CSS attribute
                              (linearize-attributes-1 
                                (cddr attr-list)
                                html-attr-string 
                                (string-append (linearize-attribute-pair-css val css-key) ";" css-attr-string)
                                (- lgt 2)
                                whole-attr-list))
                           (else                            ; HTML attribute
                             (linearize-attributes-1 
                               (cddr attr-list)
                               (string-append (linearize-attribute-pair-html val key) " " html-attr-string)
                               css-attr-string
                               (- lgt 2)
                               whole-attr-list)))))
        ((< lgt 2) (error (string-append "Linearize-attributes-1: Called with an odd length attribute list. Not a Lisp property list: " (as-string whole-attr-list))))))

; Return whether key is a css-key, for instance a key like css:k or CSS:k
; A true value is the key propper, such as k (as a string).
(define (css-key? key)
  (let* ((key-str (symbol->string key))
         (lgt (string-length key-str)))
   (if
    (and (>= lgt 4) 
         (or (eq? (string-ref key-str 0) #\c) (eq? (string-ref key-str 0) #\C))
         (or (eq? (string-ref key-str 1) #\s) (eq? (string-ref key-str 1) #\S))
         (or (eq? (string-ref key-str 2) #\s) (eq? (string-ref key-str 2) #\S))
         (eq? (string-ref key-str 3) #\:))
    (substring key-str 4 lgt)
    #f)))

(define (linearize-attribute-pair-html val key)
  (string-append (as-string key) " = " (string-it (as-string val))))

(define (linearize-attribute-pair-css val key)
  (string-append key ": " (as-string val)))

; --------------------------------------------------------------------------------------------------------------------------------
; Attribute checking.  

; Attribute tripple selectors
(define att-name (make-selector-function 1))
(define att-type (make-selector-function 2))
(define att-status (make-selector-function 3))

; Check the attributes (first par) in the calling form against the attribute definitions taken from the DTD file (second par).
; The first parameter, attribute, is the attributes of the calling form, on property list form:
; (a1 v1 ... an vn). ai is a symbol and vi is a string.
; The second parameter dtd-attribute-definition is the attributes as defined
; in the dtd for the element in question. The third parameter number-of-req-attributes is the number
; of required attributes in dtd-attr-definitions. The fourth parameter, tag-name, is the
; name of the enclosing tag. dtd-attribute-definition is a list of 
; triples (attr-name attr-type require-status). attr-name is a string, attr-type is
; a string or a list of strings (possibilities), and require-status is a string
; such as "#IMPLIED" or "#REQUIRED"
(define (check-attributes! attributes dtd-attribute-definition number-of-req-attributes tag-name)
 (if (even? (length attributes))  ; if not, we report the error elsewhere
  (let ((required-attribute-names 
           (map (compose as-symbol car) (front-sublist dtd-attribute-definition number-of-req-attributes)))
        (dtd-attribute-names (map (compose as-symbol car) dtd-attribute-definition))
        (attribute-names (if (null? attributes) '() (every-second-element attributes)))
        (attribute-values (if (null? attributes) '() (every-second-element (cdr attributes))))
       )
    (check-required-attributes! attribute-names required-attribute-names tag-name)
    (check-for-attribute-existence! attribute-names dtd-attribute-names tag-name)
    (check-for-attribute-types! attribute-names attribute-values dtd-attribute-definition tag-name)
)))


; the symbols in required-attribute-names must all be found as attribute names in the property list attributes
; if not an error is issued.
; tag-name is the name of the enclosing tag
(define (check-required-attributes! attribute-names required-attribute-names tag-name)
  (if (not (null? required-attribute-names))
      (begin
         (chek-one-required-attribute! attribute-names (car required-attribute-names) tag-name)
         (check-required-attributes! attribute-names (cdr required-attribute-names) tag-name))))

(define (chek-one-required-attribute! attribute-names required-attribute tag-name)
  (if (not (memq required-attribute attribute-names))
      (check-error (string-append "The required attribute  " (as-string required-attribute) "  is not present in the " (upcase-string tag-name) " element."))))

;; The definition of the procedure that reports validation errors.
;; The default value is display-warning, which issues non-fatal warning messages.
;; Alternative value: laml-error (fatal error messaging).
(define check-error display-warning)

; Are all names in attribute-names found in the list of names dtd-attribute-names
; tag-name is the name of the enclosing tag
; CSS attributes should not be checked for existence. 
(define (check-for-attribute-existence! attribute-names dtd-attribute-names tag-name)
   (if (not (null? attribute-names))
       (begin
         (check-one-attribute-existence! (car attribute-names) dtd-attribute-names tag-name)
         (check-for-attribute-existence! (cdr attribute-names) dtd-attribute-names tag-name))))

(define (check-one-attribute-existence! name dtd-attribute-names tag-name)
  (if (and (not (css-key? name)) (not (memq name dtd-attribute-names)))
      (check-error (string-append "The HTML attribute  " (as-string name) "  is not valid in the "  (upcase-string tag-name) " element."))))

; Check that the attributes (as splitted into attribute-names and attribute-values - list of equal lengths)
; have correct types accoring the dtd-attribute-names.
(define (check-for-attribute-types! attribute-names attribute-values dtd-attributes tag-name)
  (if (not (null? attribute-names))
      (begin
         (check-one-attribute-type! (car attribute-names) (car attribute-values) dtd-attributes tag-name)
         (check-for-attribute-types! (cdr attribute-names) (cdr attribute-values) dtd-attributes tag-name))))

(define (check-one-attribute-type! name value dtd-attributes tag-name)
  (let ((attribute-descriptor 
          (find-in-list (lambda (tripple) (eq? (as-symbol (car tripple)) name)) dtd-attributes)))
    (if attribute-descriptor
        (check-attribute-value! name value (att-type attribute-descriptor) tag-name))))

; is value a 'member of' attribute-type. value is a string.
; Attribute is a string such as "NUMBER" "CDATA" or a list of strings, in which case value must be a member.
(define (check-attribute-value! name value attribute-type tag-name)
  (cond ((list? attribute-type) 
            (if (not (member (downcase-string value) (map downcase-string attribute-type)))  ; too expensive to downcase list here 
                (check-error (string-append "The value  " (string-it value) "  of the html attribute  "
                                            (as-string name) "  is not valid in the "  (upcase-string tag-name) " element."))))
        ((equal? "NUMBER" attribute-type)
            (if (not (numeric-string? value))
                (check-error (string-append "The attribute value  " (string-it value) "  should be numeric (but enclosed in string quotes)"))))
        (else 'incomplete)  ; not implemented yet
  ))


;;; Rendering functions and procedures.
;;; The functions and procedures in this section transform the internal document representation
;;; (abstract syntax trees) to a textual form (text strings).


; --------------------------------------------------------------------------------------------------------------------------------
; HTML rendering from ASTs.
; Simple recursive processing - can probably be made better.

;(define (render ast)
; (let* ((tag-name (ast-element-name ast)) 
;        (contents-list (ast-subtrees ast))
;        (linearized-contents (linearize-contents contents-list))
;        (attribute-properlist (ast-attributes ast))
;        (kind (ast-kind ast))
;       )
;  (if (eq? kind 'double)
;      (itag-html tag-name linearized-contents attribute-properlist)
;      (itag1-html tag-name attribute-properlist))))
;
;(define (linearize-contents contents-list)
;  (linearize-contents-1 contents-list ""))
;
;; html-protecting of (car contents-list) and other possible char converting must be controlled by an array, and be made much more efficient.
;(define (linearize-contents-1 contents-list res)
;  (cond ((null? contents-list) res)
;        ((cdata? (car contents-list)) (linearize-contents-1 (cdr contents-list) (string-append res (html-text-transform (car contents-list)))))
;        ((forced-white-space? (car contents-list)) (linearize-contents-1 (cdr contents-list) (string-append res " ")))
;        ((ast? (car contents-list)) (linearize-contents-1 (cdr contents-list) (string-append res (render (car contents-list)))))))
;
;
;; Return a balanced html tag of both start and end tag, based on the parameters name (tag name) contents and attributes.
;; The attributes is supposed to be a property list of symbol string pairs.
;; The 'i' in the function name means 'internal'.
;(define (itag-html name contents attributes)
; (if (null? attributes)
;  (string-append "<" (as-string name) ">"
;                  (as-string contents)
;                  "</" name ">")
;  (let* ((attributes (linearize-attributes attributes))
;         (html-attributes (car attributes))
;         (css-attributes (cdr attributes)))
;   (string-append "<" (as-string name) " " html-attributes
;                  (if (empty-string? css-attributes) "" (string-append " style = " (string-it css-attributes)))
;                   ">"
;                  (as-string contents)
;                  "</" name ">"))))
;
;; Return a single tag of name with attributes.
;; The attributes is supposed to be a property list of symbol string pairs.
;; The 'i' in the function name means 'internal'.
;(define (itag1-html name attributes)
; (if (null? attributes)
;	 (string-append "<" (as-string name) (if xml-syntax? "/>" ">"))
;	 (let* ((attributes (linearize-attributes attributes))
;		(html-attributes (car attributes))
;		(css-attributes (cdr attributes)))
;	   (string-append "<" (as-string name) " " html-attributes 
;			  (if (empty-string? css-attributes) "" (string-append " style = " (string-it css-attributes)))
;			  (if xml-syntax? "/>" ">")
;			  ))))



; ---------------------------------------------------------------------------------------------------
; Fast AST rendering.

;; Render the html-clause (an AST) to output-port.
;; output-port is assumed to be open. output-port will not be closed by this procedure.
;; .form (render-to-output html-clause output-port [prolog epilog])
;; .parameter html-clause an AST
;; .parameter output-port an open output port
;; .parameter prolog The symbol prolog, in which case (standard-prolog) is inserted, or a prolog string to be inserted
;; .parameter epilog The symbol epilog in which case (standard-epilog) is inserted, or a epilog string to be inserted
(define (render-to-output-port html-clause output-port . optional-parameter-list)
 (let* ((prolog (optional-parameter 1 optional-parameter-list #f))
        (epilog (optional-parameter 2 optional-parameter-list #f))
        (prolog-text (cond ((and (symbol? prolog) (eq? prolog 'prolog)) (standard-prolog))
                           ((string? prolog) prolog)
                           (else "")))
        (epilog-text (cond ((and (symbol? epilog) (eq? epilog 'epilog)) (standard-epilog))
                           ((string? epilog) epilog)
                           (else "")))
        (put-fn (put-in-sink-stream-generator output-port))
       )
  (put-fn prolog-text)
  (render-fast html-clause put-fn)
  (put-fn epilog-text)))

;; Render the html-clause (an AST) and return the rendered string
;; .form (render html-clause [prolog epilog])
;; .parameter html-clause an AST
;; .parameter prolog The symbol prolog, in which case (standard-prolog) is inserted, or a prolog string to be inserted
;; .parameter epilog The symbol epilog in which case (standard-epilog) is inserted, or a epilog string to be inserted
(define (render html-clause . optional-parameter-list)
 (let* ((prolog (optional-parameter 1 optional-parameter-list #f))
        (epilog (optional-parameter 2 optional-parameter-list #f))
        (prolog-text (cond ((and (symbol? prolog) (eq? prolog 'prolog)) (standard-prolog))
                           ((string? prolog) prolog)
                           (else "")))
        (epilog-text (cond ((and (symbol? epilog) (eq? epilog 'epilog)) (standard-epilog))
                           ((string? epilog) epilog)
                           (else "")))
       )
   (reset-sink-string)
   (render-fast html-clause put-in-sink-text-string)
   (string-append
     prolog-text
     (sink-string)  
     epilog-text)))



; --------------------------------------------------------------------
; String sink in terms of segments (a list) of strings.

(define sink-string-segment-size 20000)
(define sink-string-segment-limit (- sink-string-segment-size 1))
(define output-sink-segments '())
(define output-sink-string (make-string sink-string-segment-size))
(define next-sink-ptr 0)

; Put x (string or char) into output sink.
(define (put-in-sink-text-string x)
  (cond ((char? x) 
          (begin
	   (string-set! output-sink-string next-sink-ptr x)
	   (set! next-sink-ptr (+ 1 next-sink-ptr))
           (if (= next-sink-ptr sink-string-segment-size) (prepare-next-sink-segment))))

        ((string? x)
          (do ((lgt (string-length x))
	       (i 0 (+ i 1))
               (j next-sink-ptr (if (< j sink-string-segment-limit) (+ j 1) 0))
              )
	      ((= i lgt) (set! next-sink-ptr j))
	       (string-set! output-sink-string j (string-ref x i))
               (if (= j sink-string-segment-limit) (prepare-next-sink-segment))
              ))

        (else "put-in-sink-string: Can only output chars or strings")))

(define (prepare-next-sink-segment)
 (set! output-sink-segments (cons (string-copy output-sink-string) output-sink-segments))
 (set! next-sink-ptr 0)
)

; Return the resulting sink string
(define (sink-string)
 (string-append 
   (list-to-string (reverse output-sink-segments) "")
   (substring output-sink-string 0 next-sink-ptr)))

(define (reset-sink-string)
 (set! output-sink-segments '())
 (set! next-sink-ptr 0))

; --------------------------------------------------------------------
; Stream sink.

; Generate an output port put procedure
(define (put-in-sink-stream-generator port)
 (lambda (x)
  (cond ((char? x) 
          (write-char x port))
        ((string? x)
          (do ((lgt (string-length x))
               (i 0 (+ i 1))
              )
	      ((= i lgt) 'done)
  	       (write-char (string-ref x i) port)))
        (else "put-in-sink-stream: Can only output chars or strings"))))


; --------------------------------------------------------------------
; Sink independet rendering stuff. 
; Depends on linearize-attributes and html-text-transform

(define (render-fast ast put)
 (let* ((tag-name (ast-element-name ast)) 
        (contents-list (ast-subtrees ast))
        (attribute-properlist (ast-attributes ast))
        (attributes-res (linearize-attributes attribute-properlist))
        (html-attributes-string (car attributes-res))
        (css-attributes-string (cdr attributes-res))
        (kind (ast-kind ast))
       )
  (cond ((eq? kind 'single)
          (put #\<) 
          (put tag-name) 
          (if (not (null? attribute-properlist)) 
	      (begin
	       (put #\space)
	       (put html-attributes-string)
	       (if (not (empty-string? css-attributes-string))
		   (begin (put " style = ")
			  (put #\") (put css-attributes-string) (put #\")))
	       ))
          (put (if xml-syntax? "/>" #\>)))

        ((eq? kind 'double)
          (put #\<) 
          (put tag-name) 
          (if (not (null? attribute-properlist)) 
	      (begin
	       (put #\space)
	       (put html-attributes-string)
	       (if (not (empty-string? css-attributes-string))
		   (begin (put " style = ")
			  (put #\") (put css-attributes-string) (put #\")))
	       ))
          (put #\>)
          (linearize-contents-list-fast contents-list put tag-name)
          (put "</")  (put tag-name) (put #\>))

        (error "render-fast: Either a single or double kind of ast expected."))))

(define (linearize-contents-list-fast contents-list put tag-name)
  (for-each 
    (lambda (contents) (linearize-contents-fast contents put tag-name))
    contents-list))

(define (linearize-contents-fast contents put tag-name)
  (cond ((cdata? contents) 
          (if (and transliterate-character-data? (not (member tag-name non-transliteration-elements)))
              (do ((lgt (string-length contents))
		   (i 0 (+ i 1))
		   )
		  ((= i lgt) 'done)
		(put (html-char-transform (string-ref contents i))))
              (put contents)))
        ((forced-white-space? contents) (put #\space))
        ((ast? contents) (render-fast contents put))))


 
; ---------------------------------------------------------------------------------------------------
; Contents validation. Common stuff.

(define problem-contents-list '())

; A variant of member which registers context on problem-contents-list in case (not (member el lst))
(define (member-remember el lst context)
 (let ((res (member el lst)))
   (if (not res)
       (set! problem-contents-list (cons context problem-contents-list)))
   res))

; Element constituent-list is a list of strings, namely element tag names or
; "#PCDATA".
; A true results means OK - no error
; Avoid a O(n^2) algorithm here in the final implementation
(define (one-or-more . element-constituent-list)
  (lambda (contents)
    (set! problem-contents-list '())
    (cond ((or (and (boolean? contents) (not contents))
               (and (list? contents) (null? contents))) 
             (begin
                  (set! problem-contents-list (cons "Empty contents not acceptable" problem-contents-list))
                  #f))  ; empty contents not acceptable
          ((ast? contents) (member-remember (ast-element-name contents) element-constituent-list contents))
	  ((cdata? contents) (member-remember "#pcdata" element-constituent-list contents))
	  ((forced-white-space? contents) #t)
	  ((list contents)
            (and 
	     (>= (length contents) 1)	; implement more efficienly
	     (accumulate-right
	      (lambda (x y) (and x y))
	      #t
	      (map 
	       (lambda (cont)
		 (cond ((and (boolean? cont) (not cont))
                         (begin
			   (set! problem-contents-list (cons "Empty contents not acceptable" problem-contents-list))
			   #f)) ; even a single #f is not acceptable
                       ((ast? cont) (member-remember (ast-element-name cont) element-constituent-list cont))
		       ((cdata? cont) (member-remember "#pcdata" element-constituent-list cont))
		       ((forced-white-space? cont) #t)
		       (else #f)))
	       contents)))
          )
	  (else (laml-error "one-or-more: Unknown contents: " (as-string contents))))))


(define (zero-or-more . element-constituent-list)
  (lambda (contents)
    (set! problem-contents-list '())
    (cond ((and (boolean? contents) (not contents)) #t)  ; no contents, which is acceptable
          ((ast? contents) (member-remember (ast-element-name contents) element-constituent-list contents))
	  ((cdata? contents) (member-remember "#pcdata" element-constituent-list contents))
	  ((forced-white-space? contents) #t)
	  ((list contents)
	    (accumulate-right
	     (lambda (x y) (and x y))
	     #t
	     (map 
	      (lambda (cont)
		(cond ((and (boolean? cont) (not cont)) #t) ; list no contents, which is acceptable
                      ((ast? cont) (member-remember (ast-element-name cont) element-constituent-list cont))
		      ((cdata? cont) (member-remember "#pcdata" element-constituent-list contents))
		      ((forced-white-space? cont) #t)
		      (else #f)))
	      contents))
	   )
	  (else (laml-error "one-or-more: Unknown contents: " (as-string contents))))))

; temporary:
(define (generic-checker contents)
  (set! problem-contents-list '())
  #t)


; Apply error-predicate on contents. If the validation-error-predicate returns a true result,
; issue a warning. The result is suposed to give a hint about the actual error. 
(define (validate-contents! contents validation-predicate tag-name)
 (set! problem-contents-list '())
 (let ((validation-status (validation-predicate contents)))
  (if (not validation-status)
      (let ((count (length problem-contents-list)))
        (if (> count 0) ; should always be true
          (check-error
           (string-append 
            (string-append (if (= count 1) 
                               "HTML validation error(s) encountered in an instance of the  "
                               (string-append  "HTML validation error(s) encountered in an instance of the  "))
                                                                                        ; too confusing to tell how many errors - some are double reported...
                           (upcase-string (as-string tag-name)) "  element")
            (indented-terminal-lines (map (compose truncate-string render-1) problem-contents-list)))))))))

(define (indented-terminal-lines line-list)
 (let ((sep (string-append (as-string #\newline) "  ")))
  (string-append sep (list-to-string line-list sep))))

(define (render-1 contents)
  (cond ((ast? contents) (render contents))
	((cdata? contents) contents)
	((forced-white-space? contents) "SPACE")
	((list? contents) (list-to-string (map render-1 contents) " "))
        (else "??")))

(define (truncate-string str)
 (if (> (string-length str) error-truncation-length)
     (string-append (substring str 0 error-truncation-length) "...")
     str))




; ---------------------------------------------------------------------------------------------------
; The explicitly programmed HTML 1.0 strict validation prediates.
; The majority of the predicates are produced automatically, via calls to one-or-more 
; and zero-and-more. The remaining - but interesting and important - cases are programmed
; on a case-by-case basis.


; The parameters contents is supposed to be a list of constituents of an html node.
; check them against:   "(HEAD, BODY)"
(define (html-checker contents)
 (let ((contents-1 (if (list? contents) (filter (negate white-space-related?) contents) contents)))
  (cond ((not (list? contents-1))		; #f - no contents probably
           (add-problem! (enrich-error-message "The HTML instance is not allowed to be empty" contents-1)))
	((list? contents-1)
	 (if (not
	      (and (= 2 (length contents-1))
		   (ast? (first contents-1)) (equal? (ast-element-name (first contents-1)) "head")
		   (ast? (second contents-1)) (equal? (ast-element-name (second contents-1)) "body")))
             (add-problem! (enrich-error-message "A HTML instance must consist of exactly two constituents: HEAD followed by BODY" contents-1))
	     #t))
	(else #f))))

; CDATA
(define (script-checker contents)
 (cdata-checker contents))

; CDATA
(define (style-checker contents)
 (cdata-checker contents))

; "(#PCDATA)"
; No difference between CDATA and PCDATA
(define (title-checker contents)
 (cdata-checker contents))


;"((script|style|meta|link|object)*,
;     ((title, (script|style|meta|link|object)*, (base, (script|style|meta|link|object)*)?) |
;      (base, (script|style|meta|link|object)*, (title, (script|style|meta|link|object)*))))"
; 
; There must be one title element.
; There can be one base element.
; There can be an arbitrary number of script, style, meta, link, or object elements.
;
(define (head-checker contents)
 (let* ((contents-1 (if (list? contents) (filter (negate white-space-related?) contents) contents))
        (legal-el-names 
         (list "title" "base" "script" "style" "meta" "link" "object"))
        (immediate-constituents-ok (apply zero-or-more legal-el-names))
       )
   (cond ((not (list? contents-1))
            (add-problem! (enrich-error-message 
			   (string-append "The head instance is not allowed to be empty")
			   contents-1)))

         ((not (immediate-constituents-ok contents-1))
            (add-problem! (enrich-error-message 
			   (string-append "Only title, base, script, style, meta, link, and object elements allowed in a head")
			   contents-1)))

         ((not (= (length (instances-of-ast "title" contents-1)) 1))
            (add-problem! (enrich-error-message 
			   (string-append "There must be exactly one  title  element in a head")
			   contents-1)))

         ((not (<= (length (instances-of-ast "base" contents-1)) 1))
            (add-problem! (enrich-error-message 
			   (string-append "There must be at most one  base  element in a head")
			   contents-1)))

         (else #t))))



; (caption?, (col*|colgroup*), ((thead?, tfoot?, tbody+)|(tr+)))
(define (table-checker contents)
 (let ((constituent-name 
        (lambda (x)
          (cond ((ast? x) (ast-element-name x))
                ((cdata? x) "text")
                (else "???")))))  ; never relevant
  (let ((contents-1 (if (list? contents) (filter (negate white-space-related?) contents) contents)))
    (cond ((cdata? contents-1)		
	   (add-problem! (enrich-error-message "The table instance is not allowed to contain pure text" contents-1)))
          ((or (not (list? contents-1)) (null? contents-1))		
	   (add-problem! (enrich-error-message "The instance is not allowed to be empty" contents-1)))
	  ((list? contents-1)
           (let ((actual-constituents (map constituent-name contents-1))) ; a list of tag names (strings) of table constituent. 
					; "text" means pctext.
	     (table-automata-accept? actual-constituents contents-1)
	     )
	   )
	  (else #f)))))




; (#PCDATA)
(define (textarea-checker contents)
  (cdata-checker contents))

; (#PCDATA)
(define (option-checker contents)
  (cdata-checker contents))



; "((p | h1|h2|h3|h4|h5|h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | ins | del | script | noscript)+ 
; | area+)"
(define (map-checker contents)
 (let* ((contents-1 (if (list? contents) (filter (negate white-space-related?) contents) contents))
        (other-legal-el-names
         (list "p" "h1" "h2" "h3" "h4" "h5" "h6" "div" "ul" "ol" "dl" "pre" 
          "hr" "blockquote" "address" "fieldset" "table" "form" "ins" "del" "script" "noscript"))

        (others-ok-fn (apply one-or-more other-legal-el-names))
        (area-ok-fn (apply one-or-more (list "area")))

        (others-ok (others-ok-fn contents-1)) ; only others
        (area-ok (area-ok-fn contents-1))  ; only area

       )
   (cond ((not (list? contents-1))
            (add-problem! (enrich-error-message 
			   (string-append "The map instance is not allowed to be empty")
			   contents-1)))

         (area-ok #t)

         (others-ok #t)

         (else           ; (or (not area-ok) (not others-ok)) 
            (add-problem! (enrich-error-message 
			   (string-append "One or more area elements  *XOR*  one or more p,h1,h2,h3,h4,h5,h6,div,ul,ol,dl,pre,hr,blockquote,address,fieldset,table,form,ins,del,script, noscript elements expected")
			   contents-1))))))



; ---------------------------------------------------------------------------------------------------
; Auxilary functions and procedures for HTML validation.

; Adds error message to problem-contents-list and returns #f, as an indication of validation failure.
(define (add-problem! error-message)
 (set! problem-contents-list (cons error-message problem-contents-list))
 #f)

(define (enrich-error-messages error-message-list constituent)
  (if (list? error-message-list)
      (map (lambda (e) (string-append e ": " (render-1 constituent))) error-message-list)
      error-message-list))

(define (enrich-error-message error-message constituent)
  (string-append error-message ": " (render-1 constituent)))

(define husk #f)

(define (and-fn x y) (and x y))

(define (cdata-checker contents)
 (let ((contents-1 (if (list? contents) (filter (negate white-space-related?) contents) contents)))
  (cond ((cdata? contents-1)		; #f - no contents probably
           #t)
        ((not (list? contents-1))
          (begin
	   (set! problem-contents-list 
		 (cons (enrich-error-message "The instance should not be empty" contents-1)
		       problem-contents-list))
	   #f))
	((list? contents-1)
	 (if (not
	       (accumulate-right and-fn #t (map cdata? contents-1))) ; all cdata?
	     (begin
	       (set! problem-contents-list 
		     (cons (enrich-error-message 
                             "The instance must consist of textual contents - no embedded elements allowed" contents-1)
			   problem-contents-list))
	       #f)
	     #t))
	(else #f))))

; A variant of cdata-checker, which is used for pure (#PCDATA) elements, via support of the DTD parser.
(define (pcdata-checker contents)
 (set! problem-contents-list '())
 (let ((contents-1 (if (list? contents) (filter (negate white-space-related?) contents) contents)))
  (cond ((and (list? contents) (null? contents))
          (begin
	   (set! problem-contents-list 
		 (cons (enrich-error-message "The instance should not be empty" contents-1)
		       problem-contents-list))
	   #f))
        ((cdata? contents-1)		; #f - no contents probably
           #t)
        ((not (list? contents-1))
          (begin
	   (set! problem-contents-list 
		 (cons (enrich-error-message "The instance should not be empty" contents-1)
		       problem-contents-list))
	   #f))
	((list? contents-1)
	 (if (not
	       (accumulate-right and-fn #t (map cdata? contents-1))) ; all cdata?
	     (begin
	       (set! problem-contents-list 
		     (cons (enrich-error-message 
                             "The instance must consist of textual contents - no embedded elements allowed" contents-1)
			   problem-contents-list))
	       #f)
	     #t))
	(else #f))))

; Is there an AST with el-name in the list of ASTs.
; precondition: contents is a list of ASTs
(define (there-exists-ast? el-name contents-list)
  (find-in-list (lambda (ast) (equal? (ast-element-name ast) el-name)) contents-list))

; Return the instances of ast element name in the contents list.
; precondition: contents is a list of ASTs
(define (instances-of-ast el-name contents-list)
  (filter (lambda (ast) (equal? (ast-element-name ast) el-name)) contents-list))


; Do all ASTs have element names in el-name-list
; precondition: contents is a list of ASTs
; Should not be O(n^2) in a more finished implementation
(define (all-ast-member-of? el-name-list contents-list)
 (accumulate-right and-fn #t 
  (map (lambda (ast) (member (ast-element-name ast) el-name-list)) contents-list)))

(define (filter-contents pred contents-list)
 (if (list? contents-list)
     (filter pred contents-list)
     '()))

; Check that no sub AST in contents contains any node with tag in the list element-name-list.
; contents can be a list of ASTs.
; Returns true if no occurrence of any string from element-name-list is found.
(define (deep-excluding-element-names element-name-list contents)
 (cond ((ast? contents) (deep-excluding-element-names-ast element-name-list contents))
       ((cdata? contents) #t)
       ((forced-white-space? contents) #t)
       ((white-space-related? contents) #t)
       ((list? contents)
         (accumulate-right and-fn #t  
          (map (lambda (c) (deep-excluding-element-names element-name-list c)) contents))) ; notice direct recursion
       (else (laml-error "deep-excluding-element-names: Unknown type of contents"))))

; Like deep-excluding-element-names, but with the precondition that
; the parameter - ast-contents - is in fact an AST
(define (deep-excluding-element-names-ast element-name-list ast-contents)
 (let* ((root-name (ast-element-name ast-contents))
        (mem-test (member root-name element-name-list)))
   (if mem-test
       (add-problem! 
         (enrich-error-message 
           "Encountered illegal deep constituent"
          ast-contents))
       (deep-excluding-element-names element-name-list (ast-subtrees ast-contents)))))
       
; ----------------------------------------------------------------------------------------------------------
; Table automata

(define state-list '()) ; for debugging purposes
(define debugging-table-automata #f)

; Do we accept the list of actual constituents (a list of ast node names - string).
; constituents is the corresponding ast's etc, passed for error message purposes.
(define (table-automata-accept? actual-constituent-names constituents)
 (set! state-list '())
 (call-with-current-continuation
  (lambda (exit)
    (table-automata-accept-1? actual-constituent-names constituents 0 (length actual-constituent-names) exit 'start))))

(define (table-automata-accept-1? elements constituents i inlgt failure current-state)
  (if (and (or (eq? current-state 'tbody) (eq? current-state 'tr)) (>= i inlgt))
      #t  ; accept
      (let* ((el (list-ref elements i))
             (const (list-ref constituents i))
             (next-state (table-automata-transition current-state el))
            )
       (if debugging-table-automata
            (set! state-list (cons next-state state-list)))
       (if (failure-state? next-state)
           (report-and-exit next-state el const failure))
       (table-automata-accept-1? elements constituents (+ 1 i) inlgt failure next-state))))

(define (failure-state? state)
  (memq state (list 'failure 'caption-failure 'cols-failure 'thead-failure 'tfoot-failure 'tbody-failure 'tr-failure)))

(define (report-and-exit state el const failure)
 (let ((error-message
        (cond ((eq? state 'caption-failure)
                 "caption  encountered at wrong position")
              ((eq? state 'cols-failure)
                 "col  or  colgroup  encountered at wrong position")
              ((eq? state 'thead-failure)
                 "thead encountered at wrong position")
              ((eq? state 'tfoot-failure)
                 "tfoot encountered at wrong position")
              ((eq? state 'tbody-failure)
                 "tbody  is not allowed when a tr element is present")
              ((eq? state 'tr-failure)
                 "tr  is not allowd when a thead/tfoot/tbody is present")
              (else "Only  caption, col, colgroup, thead, tfoot, tbody, and tr  allowed"))))
    (add-problem! (enrich-error-message error-message const))
    (failure #f)))

(define (table-automata-transition in-state el)
  (cond 
         ((eq? in-state 'start)
            (cond ((equal? el "caption")         'caption)
                  ((equal? el "col")             'cols)
                  ((equal? el "colgroup")        'cols)
                  ((equal? el "thead")           'thead)
                  ((equal? el "tfoot")           'tfoot)
                  ((equal? el "tbody")           'tbody)
                  ((equal? el "tr")              'tr)
                  (else                          'failure)))

         ((eq? in-state 'caption)
            (cond ((equal? el "caption")         'caption-failure)
                  ((equal? el "col")             'cols)
                  ((equal? el "colgroup")        'cols)
                  ((equal? el "thead")           'thead)
                  ((equal? el "tfoot")           'tfoot)
                  ((equal? el "tbody")           'tbody)
                  ((equal? el "tr")              'tr)
                  (else                          'failure)))

         ((eq? in-state 'cols)
            (cond ((equal? el "caption")         'caption-failure)
                  ((equal? el "col")             'cols)
                  ((equal? el "colgroup")        'cols)
                  ((equal? el "thead")           'thead)
                  ((equal? el "tfoot")           'tfoot)
                  ((equal? el "tbody")           'tbody)
                  ((equal? el "tr")              'tr)
                  (else                          'failure)))

         ((eq? in-state 'thead)
            (cond ((equal? el "caption")         'caption-failure)
                  ((equal? el "col")             'cols-failure)
                  ((equal? el "colgroup")        'cols-failure)
                  ((equal? el "thead")           'thead-failure)
                  ((equal? el "tfoot")           'tfoot)
                  ((equal? el "tbody")           'tbody)
                  ((equal? el "tr")              'tr-failure)
                  (else                          'failure)))

         ((eq? in-state 'tfoot)
            (cond ((equal? el "caption")         'caption-failure)
                  ((equal? el "col")             'cols-failure)
                  ((equal? el "colgroup")        'cols-failure)
                  ((equal? el "thead")           'thead-failure)
                  ((equal? el "tfoot")           'tfoot-failure)
                  ((equal? el "tbody")           'tbody)
                  ((equal? el "tr")              'tr-failure)
                  (else                          'failure)))

         ((eq? in-state 'tbody)
            (cond ((equal? el "caption")         'caption-failure)
                  ((equal? el "col")             'cols-failure)
                  ((equal? el "colgroup")        'cols-failure)
                  ((equal? el "thead")           'thead-failure)
                  ((equal? el "tfoot")           'tfoot-failure)
                  ((equal? el "tbody")           'tbody)
                  ((equal? el "tr")              'tr-failure)
                  (else                          'failure)))

         ((eq? in-state 'tr)
            (cond ((equal? el "caption")         'caption-failure)
                  ((equal? el "col")             'cols-failure)
                  ((equal? el "colgroup")        'cols-failure)
                  ((equal? el "thead")           'thead-failure)
                  ((equal? el "tfoot")           'tfoot-failure)
                  ((equal? el "tbody")           'tbody-failure)
                  ((equal? el "tr")              'tr)
                  (else                          'failure)))


         (else                                   (laml-error "table automata transition error 2" in-state))

  ))

; ----------------------------------------------------------------------------------------------------------
; Extra validation predicates - element prohibitions, cf. section 4.9 and appendix B of the XHTML1.0
; reformulation: http://www.w3.org/TR/xhtml1 

(define (a-extra-checker contents)
 (if (not 
       (deep-excluding-element-names 
	    (list "a")
	    contents
	    ))
     (add-problem! (enrich-error-message 
		    (string-append "a (anchor)  sub-elements of  a (anchor)  elements are prohibited")
		    contents))
     #t))

(define (pre-extra-checker contents)
 (if (not 
       (deep-excluding-element-names 
	    (list "img" "object" "big" "small" "sub" "sup")
	    contents
	    ))
     (add-problem! (enrich-error-message 
		    (string-append "img, object, big, small, sub, and sup    sub-elements of  pre  elements are prohibited")
		    contents))
     #t))

(define (button-extra-checker contents)
 (if (not 
       (deep-excluding-element-names 
	    (list "input" "select" "textarea" "label" "button" "form" "fieldset" "iframe" "isindex") 
	    contents
	    ))
     (add-problem! (enrich-error-message 
		    (string-append "input, select, textarea, label, button, form, fieldset, iframe and isindex   sub-elements of  button  elements are prohibited")
		    contents))
     #t))

(define (label-extra-checker contents)
 (if (not 
       (deep-excluding-element-names 
	    (list "lable")
	    contents
	    ))
     (add-problem! (enrich-error-message 
		    (string-append "label  sub-elements of  label  elements are prohibited")
		    contents))
     #t))

(define (form-extra-checker contents)
 (if (not 
       (deep-excluding-element-names 
	    (list "form")
	    contents
	    ))
     (add-problem! (enrich-error-message 
		    (string-append "form  sub-elements of  form  elements are prohibited")
		    contents))
     #t))


;;; The HTML basic mirror functions

;; The LAML mirror of the XHMTL1.0 (strict) <b>html</b> double tag element . <br>
;; .parameter contents The contents of the html element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "html" "surface.html#html"
;; .misc Required attributes: xmlns. <p>Optional attributes: lang, xml:lang, dir. <br><p><font size = 2>Content model: (head, body)</font>
(define (xhtml1:html contents  . attributes) (let ((attributes-of-elements (quote (("xmlns" "CDATA" "#REQUIRED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED")))) (req-n 1)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "html")) (if validate-html? (validate-contents! contents html-checker "html")) (if (and #f check-element-prohibitions?) (validate-contents! contents html-extra-checker "html")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "html" " - " "We embed 'false' in a double tag"))) (internal-ast-node "html" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>head</b> double tag element . <br>
;; .parameter contents The contents of the head element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "head" "surface.html#head"
;; .misc No required attributes. <p>Optional attributes: lang, xml:lang, dir, profile. <br><p><font size = 2>Content model: ((script|style|meta|link|object)*,      ((title, (script|style|meta|link|object)*, (base, (script|style|meta|link|object)*)?) |       (base, (script|style|meta|link|object)*, (title, (script|style|meta|link|object)*))))</font>
(define (xhtml1:head contents  . attributes) (let ((attributes-of-elements (quote (("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("profile" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "head")) (if validate-html? (validate-contents! contents head-checker "head")) (if (and #f check-element-prohibitions?) (validate-contents! contents head-extra-checker "head")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "head" " - " "We embed 'false' in a double tag"))) (internal-ast-node "head" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>title</b> double tag element . <br>
;; .parameter contents The contents of the title element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "title" "surface.html#title"
;; .misc No required attributes. <p>Optional attributes: lang, xml:lang, dir. <br><p><font size = 2>Content model: pcdata-checker</font>
(define (xhtml1:title contents  . attributes) (let ((attributes-of-elements (quote (("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "title")) (if validate-html? (validate-contents! contents pcdata-checker "title")) (if (and #f check-element-prohibitions?) (validate-contents! contents title-extra-checker "title")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "title" " - " "We embed 'false' in a double tag"))) (internal-ast-node "title" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>base</b> single tag element . <br>
;; .parameter attributes HTML and CSS attribute value pairs on Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "base" "surface.html#base"
;; .misc No required attributes. <p>Optional attributes: href. <br>
(define (xhtml1:base  . attributes) (let ((attributes-of-elements (quote (("href" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "base")) (terminal-ast-node "base" attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>meta</b> single tag element . <br>
;; .parameter attributes HTML and CSS attribute value pairs on Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "meta" "surface.html#meta"
;; .misc Required attributes: content. <p>Optional attributes: lang, xml:lang, dir, http-equiv, name, scheme. <br>
(define (xhtml1:meta  . attributes) (let ((attributes-of-elements (quote (("content" "CDATA" "#REQUIRED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("http-equiv" "CDATA" "#IMPLIED") ("name" "CDATA" "#IMPLIED") ("scheme" "CDATA" "#IMPLIED")))) (req-n 1)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "meta")) (terminal-ast-node "meta" attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>link</b> single tag element . <br>
;; .parameter attributes HTML and CSS attribute value pairs on Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "link" "surface.html#link"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, charset, href, hreflang, type, rel, rev, media. <br>
(define (xhtml1:link  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("charset" "CDATA" "#IMPLIED") ("href" "CDATA" "#IMPLIED") ("hreflang" "CDATA" "#IMPLIED") ("type" "CDATA" "#IMPLIED") ("rel" "CDATA" "#IMPLIED") ("rev" "CDATA" "#IMPLIED") ("media" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "link")) (terminal-ast-node "link" attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>style</b> double tag element . <br>
;; .parameter contents The contents of the style element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "style" "surface.html#style"
;; .misc Required attributes: type. <p>Optional attributes: lang, xml:lang, dir, media, title, xml:space. <br><p><font size = 2>Content model: pcdata-checker</font>
(define (xhtml1:style contents  . attributes) (let ((attributes-of-elements (quote (("type" "CDATA" "#REQUIRED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("media" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("xml:space" "CDATA" "#FIXED")))) (req-n 1)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "style")) (if validate-html? (validate-contents! contents pcdata-checker "style")) (if (and #f check-element-prohibitions?) (validate-contents! contents style-extra-checker "style")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "style" " - " "We embed 'false' in a double tag"))) (internal-ast-node "style" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>script</b> double tag element . <br>
;; .parameter contents The contents of the script element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "script" "surface.html#script"
;; .misc Required attributes: type. <p>Optional attributes: charset, src, defer, xml:space. <br><p><font size = 2>Content model: pcdata-checker</font>
(define (xhtml1:script contents  . attributes) (let ((attributes-of-elements (quote (("type" "CDATA" "#REQUIRED") ("charset" "CDATA" "#IMPLIED") ("src" "CDATA" "#IMPLIED") ("defer" ("defer") "#IMPLIED") ("xml:space" "CDATA" "#FIXED")))) (req-n 1)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "script")) (if validate-html? (validate-contents! contents pcdata-checker "script")) (if (and #f check-element-prohibitions?) (validate-contents! contents script-extra-checker "script")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "script" " - " "We embed 'false' in a double tag"))) (internal-ast-node "script" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>noscript</b> double tag element . <br>
;; .parameter contents The contents of the noscript element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "noscript" "surface.html#noscript"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | ins | del | script | noscript)*</font>
(define (xhtml1:noscript contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "noscript")) (if validate-html? (validate-contents! contents (zero-or-more "p" "h1" "h2" "h3" "h4" "h5" "h6" "div" "ul" "ol" "dl" "pre" "hr" "blockquote" "address" "fieldset" "table" "form" "ins" "del" "script" "noscript") "noscript")) (if (and #f check-element-prohibitions?) (validate-contents! contents noscript-extra-checker "noscript")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "noscript" " - " "We embed 'false' in a double tag"))) (internal-ast-node "noscript" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>body</b> double tag element . <br>
;; .parameter contents The contents of the body element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "body" "surface.html#body"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, onload, onunload. <br><p><font size = 2>Content model: (p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | ins | del | script | noscript)*</font>
(define (xhtml1:body contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("onload" "CDATA" "#IMPLIED") ("onunload" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "body")) (if validate-html? (validate-contents! contents (zero-or-more "p" "h1" "h2" "h3" "h4" "h5" "h6" "div" "ul" "ol" "dl" "pre" "hr" "blockquote" "address" "fieldset" "table" "form" "ins" "del" "script" "noscript") "body")) (if (and #f check-element-prohibitions?) (validate-contents! contents body-extra-checker "body")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "body" " - " "We embed 'false' in a double tag"))) (internal-ast-node "body" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>div</b> double tag element . <br>
;; .parameter contents The contents of the div element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "div" "surface.html#div"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:div contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "div")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "p" "h1" "h2" "h3" "h4" "h5" "h6" "div" "ul" "ol" "dl" "pre" "hr" "blockquote" "address" "fieldset" "table" "form" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "div")) (if (and #f check-element-prohibitions?) (validate-contents! contents div-extra-checker "div")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "div" " - " "We embed 'false' in a double tag"))) (internal-ast-node "div" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>p</b> double tag element . <br>
;; .parameter contents The contents of the p element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "p" "surface.html#p"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:p contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "p")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "p")) (if (and #f check-element-prohibitions?) (validate-contents! contents p-extra-checker "p")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "p" " - " "We embed 'false' in a double tag"))) (internal-ast-node "p" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>h1</b> double tag element . <br>
;; .parameter contents The contents of the h1 element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "h1" "surface.html#h1"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:h1 contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "h1")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "h1")) (if (and #f check-element-prohibitions?) (validate-contents! contents h1-extra-checker "h1")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "h1" " - " "We embed 'false' in a double tag"))) (internal-ast-node "h1" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>h2</b> double tag element . <br>
;; .parameter contents The contents of the h2 element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "h2" "surface.html#h2"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:h2 contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "h2")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "h2")) (if (and #f check-element-prohibitions?) (validate-contents! contents h2-extra-checker "h2")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "h2" " - " "We embed 'false' in a double tag"))) (internal-ast-node "h2" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>h3</b> double tag element . <br>
;; .parameter contents The contents of the h3 element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "h3" "surface.html#h3"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:h3 contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "h3")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "h3")) (if (and #f check-element-prohibitions?) (validate-contents! contents h3-extra-checker "h3")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "h3" " - " "We embed 'false' in a double tag"))) (internal-ast-node "h3" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>h4</b> double tag element . <br>
;; .parameter contents The contents of the h4 element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "h4" "surface.html#h4"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:h4 contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "h4")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "h4")) (if (and #f check-element-prohibitions?) (validate-contents! contents h4-extra-checker "h4")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "h4" " - " "We embed 'false' in a double tag"))) (internal-ast-node "h4" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>h5</b> double tag element . <br>
;; .parameter contents The contents of the h5 element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "h5" "surface.html#h5"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:h5 contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "h5")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "h5")) (if (and #f check-element-prohibitions?) (validate-contents! contents h5-extra-checker "h5")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "h5" " - " "We embed 'false' in a double tag"))) (internal-ast-node "h5" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>h6</b> double tag element . <br>
;; .parameter contents The contents of the h6 element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "h6" "surface.html#h6"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:h6 contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "h6")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "h6")) (if (and #f check-element-prohibitions?) (validate-contents! contents h6-extra-checker "h6")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "h6" " - " "We embed 'false' in a double tag"))) (internal-ast-node "h6" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>ul</b> double tag element . <br>
;; .parameter contents The contents of the ul element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "ul" "surface.html#ul"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (li)+</font>
(define (xhtml1:ul contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "ul")) (if validate-html? (validate-contents! contents (one-or-more "li") "ul")) (if (and #f check-element-prohibitions?) (validate-contents! contents ul-extra-checker "ul")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "ul" " - " "We embed 'false' in a double tag"))) (internal-ast-node "ul" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>ol</b> double tag element . <br>
;; .parameter contents The contents of the ol element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "ol" "surface.html#ol"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (li)+</font>
(define (xhtml1:ol contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "ol")) (if validate-html? (validate-contents! contents (one-or-more "li") "ol")) (if (and #f check-element-prohibitions?) (validate-contents! contents ol-extra-checker "ol")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "ol" " - " "We embed 'false' in a double tag"))) (internal-ast-node "ol" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>li</b> double tag element . <br>
;; .parameter contents The contents of the li element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "li" "surface.html#li"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:li contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "li")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "p" "h1" "h2" "h3" "h4" "h5" "h6" "div" "ul" "ol" "dl" "pre" "hr" "blockquote" "address" "fieldset" "table" "form" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "li")) (if (and #f check-element-prohibitions?) (validate-contents! contents li-extra-checker "li")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "li" " - " "We embed 'false' in a double tag"))) (internal-ast-node "li" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>dl</b> double tag element . <br>
;; .parameter contents The contents of the dl element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "dl" "surface.html#dl"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (dt | dd)+</font>
(define (xhtml1:dl contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "dl")) (if validate-html? (validate-contents! contents (one-or-more "dt" "dd") "dl")) (if (and #f check-element-prohibitions?) (validate-contents! contents dl-extra-checker "dl")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "dl" " - " "We embed 'false' in a double tag"))) (internal-ast-node "dl" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>dt</b> double tag element . <br>
;; .parameter contents The contents of the dt element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "dt" "surface.html#dt"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:dt contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "dt")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "dt")) (if (and #f check-element-prohibitions?) (validate-contents! contents dt-extra-checker "dt")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "dt" " - " "We embed 'false' in a double tag"))) (internal-ast-node "dt" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>dd</b> double tag element . <br>
;; .parameter contents The contents of the dd element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "dd" "surface.html#dd"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:dd contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "dd")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "p" "h1" "h2" "h3" "h4" "h5" "h6" "div" "ul" "ol" "dl" "pre" "hr" "blockquote" "address" "fieldset" "table" "form" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "dd")) (if (and #f check-element-prohibitions?) (validate-contents! contents dd-extra-checker "dd")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "dd" " - " "We embed 'false' in a double tag"))) (internal-ast-node "dd" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>address</b> double tag element . <br>
;; .parameter contents The contents of the address element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "address" "surface.html#address"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:address contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "address")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "address")) (if (and #f check-element-prohibitions?) (validate-contents! contents address-extra-checker "address")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "address" " - " "We embed 'false' in a double tag"))) (internal-ast-node "address" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>hr</b> single tag element . <br>
;; .parameter attributes HTML and CSS attribute value pairs on Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "hr" "surface.html#hr"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
(define (xhtml1:hr  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "hr")) (terminal-ast-node "hr" attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>pre</b> double tag element . <br>
;; .parameter contents The contents of the pre element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "pre" "surface.html#pre"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, xml:space. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | map | tt | i | b | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button)*</font>
(define (xhtml1:pre contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("xml:space" "CDATA" "#FIXED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "pre")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "map" "tt" "i" "b" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button") "pre")) (if (and #t check-element-prohibitions?) (validate-contents! contents pre-extra-checker "pre")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "pre" " - " "We embed 'false' in a double tag"))) (internal-ast-node "pre" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>blockquote</b> double tag element . <br>
;; .parameter contents The contents of the blockquote element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "blockquote" "surface.html#blockquote"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, cite. <br><p><font size = 2>Content model: (p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | ins | del | script | noscript)*</font>
(define (xhtml1:blockquote contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("cite" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "blockquote")) (if validate-html? (validate-contents! contents (zero-or-more "p" "h1" "h2" "h3" "h4" "h5" "h6" "div" "ul" "ol" "dl" "pre" "hr" "blockquote" "address" "fieldset" "table" "form" "ins" "del" "script" "noscript") "blockquote")) (if (and #f check-element-prohibitions?) (validate-contents! contents blockquote-extra-checker "blockquote")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "blockquote" " - " "We embed 'false' in a double tag"))) (internal-ast-node "blockquote" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>ins</b> double tag element . <br>
;; .parameter contents The contents of the ins element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "ins" "surface.html#ins"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, cite, datetime. <br><p><font size = 2>Content model: (#pcdata | p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:ins contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("cite" "CDATA" "#IMPLIED") ("datetime" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "ins")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "p" "h1" "h2" "h3" "h4" "h5" "h6" "div" "ul" "ol" "dl" "pre" "hr" "blockquote" "address" "fieldset" "table" "form" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "ins")) (if (and #f check-element-prohibitions?) (validate-contents! contents ins-extra-checker "ins")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "ins" " - " "We embed 'false' in a double tag"))) (internal-ast-node "ins" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>del</b> double tag element . <br>
;; .parameter contents The contents of the del element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "del" "surface.html#del"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, cite, datetime. <br><p><font size = 2>Content model: (#pcdata | p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:del contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("cite" "CDATA" "#IMPLIED") ("datetime" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "del")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "p" "h1" "h2" "h3" "h4" "h5" "h6" "div" "ul" "ol" "dl" "pre" "hr" "blockquote" "address" "fieldset" "table" "form" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "del")) (if (and #f check-element-prohibitions?) (validate-contents! contents del-extra-checker "del")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "del" " - " "We embed 'false' in a double tag"))) (internal-ast-node "del" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>a</b> double tag element . <br>
;; .parameter contents The contents of the a element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "a" "surface.html#a"
;; .misc No required attributes. <p>Optional attributes: lang, xml:lang, dir, id, class, style, title, charset, type, name, href, hreflang, rel, rev, accesskey, shape, coords, tabindex, onfocus, onblur. <br><p><font size = 2>Content model: (#pcdata | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:a contents  . attributes) (let ((attributes-of-elements (quote (("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("id" "NMTOKEN" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("charset" "CDATA" "#IMPLIED") ("type" "CDATA" "#IMPLIED") ("name" "ID" "#IMPLIED") ("href" "CDATA" "#IMPLIED") ("hreflang" "CDATA" "#IMPLIED") ("rel" "CDATA" "#IMPLIED") ("rev" "CDATA" "#IMPLIED") ("accesskey" "CDATA" "#IMPLIED") ("shape" ("rect" "circle" "poly" "default") ""rect"") ("coords" "CDATA" "#IMPLIED") ("tabindex" "CDATA" "#IMPLIED") ("onfocus" "CDATA" "#IMPLIED") ("onblur" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "a")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "a")) (if (and #t check-element-prohibitions?) (validate-contents! contents a-extra-checker "a")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "a" " - " "We embed 'false' in a double tag"))) (internal-ast-node "a" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>span</b> double tag element . <br>
;; .parameter contents The contents of the span element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "span" "surface.html#span"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:span contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "span")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "span")) (if (and #f check-element-prohibitions?) (validate-contents! contents span-extra-checker "span")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "span" " - " "We embed 'false' in a double tag"))) (internal-ast-node "span" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>bdo</b> double tag element . <br>
;; .parameter contents The contents of the bdo element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "bdo" "surface.html#bdo"
;; .misc Required attributes: dir. <p>Optional attributes: id, class, style, title, lang, xml:lang. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:bdo contents  . attributes) (let ((attributes-of-elements (quote (("dir" ("ltr" "rtl") "#REQUIRED") ("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED")))) (req-n 1)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "bdo")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "bdo")) (if (and #f check-element-prohibitions?) (validate-contents! contents bdo-extra-checker "bdo")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "bdo" " - " "We embed 'false' in a double tag"))) (internal-ast-node "bdo" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>br</b> single tag element . <br>
;; .parameter attributes HTML and CSS attribute value pairs on Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "br" "surface.html#br"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title. <br>
(define (xhtml1:br  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "br")) (terminal-ast-node "br" attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>em</b> double tag element . <br>
;; .parameter contents The contents of the em element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "em" "surface.html#em"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:em contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "em")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "em")) (if (and #f check-element-prohibitions?) (validate-contents! contents em-extra-checker "em")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "em" " - " "We embed 'false' in a double tag"))) (internal-ast-node "em" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>strong</b> double tag element . <br>
;; .parameter contents The contents of the strong element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "strong" "surface.html#strong"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:strong contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "strong")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "strong")) (if (and #f check-element-prohibitions?) (validate-contents! contents strong-extra-checker "strong")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "strong" " - " "We embed 'false' in a double tag"))) (internal-ast-node "strong" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>dfn</b> double tag element . <br>
;; .parameter contents The contents of the dfn element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "dfn" "surface.html#dfn"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:dfn contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "dfn")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "dfn")) (if (and #f check-element-prohibitions?) (validate-contents! contents dfn-extra-checker "dfn")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "dfn" " - " "We embed 'false' in a double tag"))) (internal-ast-node "dfn" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>code</b> double tag element . <br>
;; .parameter contents The contents of the code element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "code" "surface.html#code"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:code contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "code")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "code")) (if (and #f check-element-prohibitions?) (validate-contents! contents code-extra-checker "code")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "code" " - " "We embed 'false' in a double tag"))) (internal-ast-node "code" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>samp</b> double tag element . <br>
;; .parameter contents The contents of the samp element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "samp" "surface.html#samp"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:samp contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "samp")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "samp")) (if (and #f check-element-prohibitions?) (validate-contents! contents samp-extra-checker "samp")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "samp" " - " "We embed 'false' in a double tag"))) (internal-ast-node "samp" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>kbd</b> double tag element . <br>
;; .parameter contents The contents of the kbd element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "kbd" "surface.html#kbd"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:kbd contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "kbd")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "kbd")) (if (and #f check-element-prohibitions?) (validate-contents! contents kbd-extra-checker "kbd")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "kbd" " - " "We embed 'false' in a double tag"))) (internal-ast-node "kbd" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>var</b> double tag element . <br>
;; .parameter contents The contents of the var element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "var" "surface.html#var"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:var contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "var")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "var")) (if (and #f check-element-prohibitions?) (validate-contents! contents var-extra-checker "var")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "var" " - " "We embed 'false' in a double tag"))) (internal-ast-node "var" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>cite</b> double tag element . <br>
;; .parameter contents The contents of the cite element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "cite" "surface.html#cite"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:cite contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "cite")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "cite")) (if (and #f check-element-prohibitions?) (validate-contents! contents cite-extra-checker "cite")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "cite" " - " "We embed 'false' in a double tag"))) (internal-ast-node "cite" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>abbr</b> double tag element . <br>
;; .parameter contents The contents of the abbr element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "abbr" "surface.html#abbr"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:abbr contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "abbr")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "abbr")) (if (and #f check-element-prohibitions?) (validate-contents! contents abbr-extra-checker "abbr")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "abbr" " - " "We embed 'false' in a double tag"))) (internal-ast-node "abbr" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>acronym</b> double tag element . <br>
;; .parameter contents The contents of the acronym element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "acronym" "surface.html#acronym"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:acronym contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "acronym")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "acronym")) (if (and #f check-element-prohibitions?) (validate-contents! contents acronym-extra-checker "acronym")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "acronym" " - " "We embed 'false' in a double tag"))) (internal-ast-node "acronym" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>q</b> double tag element . <br>
;; .parameter contents The contents of the q element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "q" "surface.html#q"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, cite. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:q contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("cite" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "q")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "q")) (if (and #f check-element-prohibitions?) (validate-contents! contents q-extra-checker "q")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "q" " - " "We embed 'false' in a double tag"))) (internal-ast-node "q" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>sub</b> double tag element . <br>
;; .parameter contents The contents of the sub element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "sub" "surface.html#sub"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:sub contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "sub")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "sub")) (if (and #f check-element-prohibitions?) (validate-contents! contents sub-extra-checker "sub")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "sub" " - " "We embed 'false' in a double tag"))) (internal-ast-node "sub" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>sup</b> double tag element . <br>
;; .parameter contents The contents of the sup element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "sup" "surface.html#sup"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:sup contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "sup")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "sup")) (if (and #f check-element-prohibitions?) (validate-contents! contents sup-extra-checker "sup")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "sup" " - " "We embed 'false' in a double tag"))) (internal-ast-node "sup" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>tt</b> double tag element . <br>
;; .parameter contents The contents of the tt element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "tt" "surface.html#tt"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:tt contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "tt")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "tt")) (if (and #f check-element-prohibitions?) (validate-contents! contents tt-extra-checker "tt")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "tt" " - " "We embed 'false' in a double tag"))) (internal-ast-node "tt" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>i</b> double tag element . <br>
;; .parameter contents The contents of the i element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "i" "surface.html#i"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:i contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "i")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "i")) (if (and #f check-element-prohibitions?) (validate-contents! contents i-extra-checker "i")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "i" " - " "We embed 'false' in a double tag"))) (internal-ast-node "i" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>b</b> double tag element . <br>
;; .parameter contents The contents of the b element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "b" "surface.html#b"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:b contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "b")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "b")) (if (and #f check-element-prohibitions?) (validate-contents! contents b-extra-checker "b")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "b" " - " "We embed 'false' in a double tag"))) (internal-ast-node "b" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>big</b> double tag element . <br>
;; .parameter contents The contents of the big element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "big" "surface.html#big"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:big contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "big")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "big")) (if (and #f check-element-prohibitions?) (validate-contents! contents big-extra-checker "big")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "big" " - " "We embed 'false' in a double tag"))) (internal-ast-node "big" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>small</b> double tag element . <br>
;; .parameter contents The contents of the small element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "small" "surface.html#small"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:small contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "small")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "small")) (if (and #f check-element-prohibitions?) (validate-contents! contents small-extra-checker "small")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "small" " - " "We embed 'false' in a double tag"))) (internal-ast-node "small" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>object</b> double tag element . <br>
;; .parameter contents The contents of the object element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "object" "surface.html#object"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, declare, classid, codebase, data, type, codetype, archive, standby, height, width, usemap, name, tabindex. <br><p><font size = 2>Content model: (#pcdata | param | p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:object contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("declare" ("declare") "#IMPLIED") ("classid" "CDATA" "#IMPLIED") ("codebase" "CDATA" "#IMPLIED") ("data" "CDATA" "#IMPLIED") ("type" "CDATA" "#IMPLIED") ("codetype" "CDATA" "#IMPLIED") ("archive" "CDATA" "#IMPLIED") ("standby" "CDATA" "#IMPLIED") ("height" "CDATA" "#IMPLIED") ("width" "CDATA" "#IMPLIED") ("usemap" "CDATA" "#IMPLIED") ("name" "CDATA" "#IMPLIED") ("tabindex" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "object")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "param" "p" "h1" "h2" "h3" "h4" "h5" "h6" "div" "ul" "ol" "dl" "pre" "hr" "blockquote" "address" "fieldset" "table" "form" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "object")) (if (and #f check-element-prohibitions?) (validate-contents! contents object-extra-checker "object")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "object" " - " "We embed 'false' in a double tag"))) (internal-ast-node "object" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>param</b> single tag element . <br>
;; .parameter attributes HTML and CSS attribute value pairs on Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "param" "surface.html#param"
;; .misc Required attributes: name. <p>Optional attributes: id, value, valuetype, type. <br>
(define (xhtml1:param  . attributes) (let ((attributes-of-elements (quote (("name" "CDATA" "#REQUIRED") ("id" "ID" "#IMPLIED") ("value" "CDATA" "#IMPLIED") ("valuetype" ("data" "ref" "object") ""data"") ("type" "CDATA" "#IMPLIED")))) (req-n 1)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "param")) (terminal-ast-node "param" attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>img</b> single tag element . <br>
;; .parameter attributes HTML and CSS attribute value pairs on Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "img" "surface.html#img"
;; .misc Required attributes: src, alt. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, longdesc, height, width, usemap, ismap. <br>
(define (xhtml1:img  . attributes) (let ((attributes-of-elements (quote (("src" "CDATA" "#REQUIRED") ("alt" "CDATA" "#REQUIRED") ("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("longdesc" "CDATA" "#IMPLIED") ("height" "CDATA" "#IMPLIED") ("width" "CDATA" "#IMPLIED") ("usemap" "CDATA" "#IMPLIED") ("ismap" ("ismap") "#IMPLIED")))) (req-n 2)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "img")) (terminal-ast-node "img" attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>map</b> double tag element . <br>
;; .parameter contents The contents of the map element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "map" "surface.html#map"
;; .misc Required attributes: name. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: ((p | h1|h2|h3|h4|h5|h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | ins | del | script | noscript)+ | area+)</font>
(define (xhtml1:map contents  . attributes) (let ((attributes-of-elements (quote (("name" "CDATA" "#REQUIRED") ("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 1)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "map")) (if validate-html? (validate-contents! contents map-checker "map")) (if (and #f check-element-prohibitions?) (validate-contents! contents map-extra-checker "map")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "map" " - " "We embed 'false' in a double tag"))) (internal-ast-node "map" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>area</b> single tag element . <br>
;; .parameter attributes HTML and CSS attribute value pairs on Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "area" "surface.html#area"
;; .misc Required attributes: alt. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, shape, coords, href, nohref, tabindex, accesskey, onfocus, onblur. <br>
(define (xhtml1:area  . attributes) (let ((attributes-of-elements (quote (("alt" "CDATA" "#REQUIRED") ("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("shape" ("rect" "circle" "poly" "default") ""rect"") ("coords" "CDATA" "#IMPLIED") ("href" "CDATA" "#IMPLIED") ("nohref" ("nohref") "#IMPLIED") ("tabindex" "CDATA" "#IMPLIED") ("accesskey" "CDATA" "#IMPLIED") ("onfocus" "CDATA" "#IMPLIED") ("onblur" "CDATA" "#IMPLIED")))) (req-n 1)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "area")) (terminal-ast-node "area" attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>form</b> double tag element . <br>
;; .parameter contents The contents of the form element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "form" "surface.html#form"
;; .misc Required attributes: action. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, method, enctype, onsubmit, onreset, accept, accept-charset. <br><p><font size = 2>Content model: (#pcdata | p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | ins | del | script | noscript)*</font>
(define (xhtml1:form contents  . attributes) (let ((attributes-of-elements (quote (("action" "CDATA" "#REQUIRED") ("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("method" ("get" "post") ""get"") ("enctype" "CDATA" ""application/x-www-form-urlencoded"") ("onsubmit" "CDATA" "#IMPLIED") ("onreset" "CDATA" "#IMPLIED") ("accept" "CDATA" "#IMPLIED") ("accept-charset" "CDATA" "#IMPLIED")))) (req-n 1)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "form")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "p" "h1" "h2" "h3" "h4" "h5" "h6" "div" "ul" "ol" "dl" "pre" "hr" "blockquote" "address" "fieldset" "table" "ins" "del" "script" "noscript") "form")) (if (and #t check-element-prohibitions?) (validate-contents! contents form-extra-checker "form")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "form" " - " "We embed 'false' in a double tag"))) (internal-ast-node "form" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>label</b> double tag element . <br>
;; .parameter contents The contents of the label element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "label" "surface.html#label"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, for, accesskey, onfocus, onblur. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:label contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("for" "IDREF" "#IMPLIED") ("accesskey" "CDATA" "#IMPLIED") ("onfocus" "CDATA" "#IMPLIED") ("onblur" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "label")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "label")) (if (and #t check-element-prohibitions?) (validate-contents! contents label-extra-checker "label")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "label" " - " "We embed 'false' in a double tag"))) (internal-ast-node "label" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>input</b> single tag element . <br>
;; .parameter attributes HTML and CSS attribute value pairs on Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "input" "surface.html#input"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, type, name, value, checked, disabled, readonly, size, maxlength, src, alt, usemap, tabindex, accesskey, onfocus, onblur, onselect, onchange, accept. <br>
(define (xhtml1:input  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("type" ("text" "password" "checkbox" "radio" "submit" "reset" "file" "hidden" "image" "button") ""text"") ("name" "CDATA" "#IMPLIED") ("value" "CDATA" "#IMPLIED") ("checked" ("checked") "#IMPLIED") ("disabled" ("disabled") "#IMPLIED") ("readonly" ("readonly") "#IMPLIED") ("size" "CDATA" "#IMPLIED") ("maxlength" "CDATA" "#IMPLIED") ("src" "CDATA" "#IMPLIED") ("alt" "CDATA" "#IMPLIED") ("usemap" "CDATA" "#IMPLIED") ("tabindex" "CDATA" "#IMPLIED") ("accesskey" "CDATA" "#IMPLIED") ("onfocus" "CDATA" "#IMPLIED") ("onblur" "CDATA" "#IMPLIED") ("onselect" "CDATA" "#IMPLIED") ("onchange" "CDATA" "#IMPLIED") ("accept" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "input")) (terminal-ast-node "input" attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>select</b> double tag element . <br>
;; .parameter contents The contents of the select element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "select" "surface.html#select"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, name, size, multiple, disabled, tabindex, onfocus, onblur, onchange. <br><p><font size = 2>Content model: (optgroup | option)+</font>
(define (xhtml1:select contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("name" "CDATA" "#IMPLIED") ("size" "CDATA" "#IMPLIED") ("multiple" ("multiple") "#IMPLIED") ("disabled" ("disabled") "#IMPLIED") ("tabindex" "CDATA" "#IMPLIED") ("onfocus" "CDATA" "#IMPLIED") ("onblur" "CDATA" "#IMPLIED") ("onchange" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "select")) (if validate-html? (validate-contents! contents (one-or-more "optgroup" "option") "select")) (if (and #f check-element-prohibitions?) (validate-contents! contents select-extra-checker "select")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "select" " - " "We embed 'false' in a double tag"))) (internal-ast-node "select" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>optgroup</b> double tag element . <br>
;; .parameter contents The contents of the optgroup element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "optgroup" "surface.html#optgroup"
;; .misc Required attributes: label. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, disabled. <br><p><font size = 2>Content model: (option)+</font>
(define (xhtml1:optgroup contents  . attributes) (let ((attributes-of-elements (quote (("label" "CDATA" "#REQUIRED") ("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("disabled" ("disabled") "#IMPLIED")))) (req-n 1)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "optgroup")) (if validate-html? (validate-contents! contents (one-or-more "option") "optgroup")) (if (and #f check-element-prohibitions?) (validate-contents! contents optgroup-extra-checker "optgroup")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "optgroup" " - " "We embed 'false' in a double tag"))) (internal-ast-node "optgroup" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>option</b> double tag element . <br>
;; .parameter contents The contents of the option element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "option" "surface.html#option"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, selected, disabled, label, value. <br><p><font size = 2>Content model: pcdata-checker</font>
(define (xhtml1:option contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("selected" ("selected") "#IMPLIED") ("disabled" ("disabled") "#IMPLIED") ("label" "CDATA" "#IMPLIED") ("value" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "option")) (if validate-html? (validate-contents! contents pcdata-checker "option")) (if (and #f check-element-prohibitions?) (validate-contents! contents option-extra-checker "option")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "option" " - " "We embed 'false' in a double tag"))) (internal-ast-node "option" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>textarea</b> double tag element . <br>
;; .parameter contents The contents of the textarea element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "textarea" "surface.html#textarea"
;; .misc Required attributes: rows, cols. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, name, disabled, readonly, tabindex, accesskey, onfocus, onblur, onselect, onchange. <br><p><font size = 2>Content model: pcdata-checker</font>
(define (xhtml1:textarea contents  . attributes) (let ((attributes-of-elements (quote (("rows" "CDATA" "#REQUIRED") ("cols" "CDATA" "#REQUIRED") ("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("name" "CDATA" "#IMPLIED") ("disabled" ("disabled") "#IMPLIED") ("readonly" ("readonly") "#IMPLIED") ("tabindex" "CDATA" "#IMPLIED") ("accesskey" "CDATA" "#IMPLIED") ("onfocus" "CDATA" "#IMPLIED") ("onblur" "CDATA" "#IMPLIED") ("onselect" "CDATA" "#IMPLIED") ("onchange" "CDATA" "#IMPLIED")))) (req-n 2)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "textarea")) (if validate-html? (validate-contents! contents pcdata-checker "textarea")) (if (and #f check-element-prohibitions?) (validate-contents! contents textarea-extra-checker "textarea")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "textarea" " - " "We embed 'false' in a double tag"))) (internal-ast-node "textarea" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>fieldset</b> double tag element . <br>
;; .parameter contents The contents of the fieldset element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "fieldset" "surface.html#fieldset"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | legend | p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:fieldset contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "fieldset")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "legend" "p" "h1" "h2" "h3" "h4" "h5" "h6" "div" "ul" "ol" "dl" "pre" "hr" "blockquote" "address" "fieldset" "table" "form" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "fieldset")) (if (and #f check-element-prohibitions?) (validate-contents! contents fieldset-extra-checker "fieldset")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "fieldset" " - " "We embed 'false' in a double tag"))) (internal-ast-node "fieldset" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>legend</b> double tag element . <br>
;; .parameter contents The contents of the legend element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "legend" "surface.html#legend"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, accesskey. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:legend contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("accesskey" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "legend")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "legend")) (if (and #f check-element-prohibitions?) (validate-contents! contents legend-extra-checker "legend")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "legend" " - " "We embed 'false' in a double tag"))) (internal-ast-node "legend" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>button</b> double tag element . <br>
;; .parameter contents The contents of the button element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "button" "surface.html#button"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, name, value, type, disabled, tabindex, accesskey, onfocus, onblur. <br><p><font size = 2>Content model: (#pcdata | p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | table | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | ins | del | script | noscript)*</font>
(define (xhtml1:button contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("name" "CDATA" "#IMPLIED") ("value" "CDATA" "#IMPLIED") ("type" ("button" "submit" "reset") ""submit"") ("disabled" ("disabled") "#IMPLIED") ("tabindex" "CDATA" "#IMPLIED") ("accesskey" "CDATA" "#IMPLIED") ("onfocus" "CDATA" "#IMPLIED") ("onblur" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "button")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "p" "h1" "h2" "h3" "h4" "h5" "h6" "div" "ul" "ol" "dl" "pre" "hr" "blockquote" "address" "table" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "ins" "del" "script" "noscript") "button")) (if (and #t check-element-prohibitions?) (validate-contents! contents button-extra-checker "button")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "button" " - " "We embed 'false' in a double tag"))) (internal-ast-node "button" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>table</b> double tag element . <br>
;; .parameter contents The contents of the table element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "table" "surface.html#table"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, summary, width, border, frame, rules, cellspacing, cellpadding. <br><p><font size = 2>Content model: (caption?, (col*|colgroup*), ((thead?, tfoot?, tbody+)|(tr+)))</font>
(define (xhtml1:table contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("summary" "CDATA" "#IMPLIED") ("width" "CDATA" "#IMPLIED") ("border" "CDATA" "#IMPLIED") ("frame" ("void" "above" "below" "hsides" "lhs" "rhs" "vsides" "box" "border") "#IMPLIED") ("rules" ("none" "groups" "rows" "cols" "all") "#IMPLIED") ("cellspacing" "CDATA" "#IMPLIED") ("cellpadding" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "table")) (if validate-html? (validate-contents! contents table-checker "table")) (if (and #f check-element-prohibitions?) (validate-contents! contents table-extra-checker "table")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "table" " - " "We embed 'false' in a double tag"))) (internal-ast-node "table" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>caption</b> double tag element . <br>
;; .parameter contents The contents of the caption element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "caption" "surface.html#caption"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br><p><font size = 2>Content model: (#pcdata | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:caption contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "caption")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "caption")) (if (and #f check-element-prohibitions?) (validate-contents! contents caption-extra-checker "caption")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "caption" " - " "We embed 'false' in a double tag"))) (internal-ast-node "caption" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>thead</b> double tag element . <br>
;; .parameter contents The contents of the thead element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "thead" "surface.html#thead"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align, char, charoff, valign. <br><p><font size = 2>Content model: (tr)+</font>
(define (xhtml1:thead contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("align" ("left" "center" "right" "justify" "char") "#IMPLIED") ("char" "CDATA" "#IMPLIED") ("charoff" "CDATA" "#IMPLIED") ("valign" ("top" "middle" "bottom" "baseline") "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "thead")) (if validate-html? (validate-contents! contents (one-or-more "tr") "thead")) (if (and #f check-element-prohibitions?) (validate-contents! contents thead-extra-checker "thead")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "thead" " - " "We embed 'false' in a double tag"))) (internal-ast-node "thead" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>tfoot</b> double tag element . <br>
;; .parameter contents The contents of the tfoot element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "tfoot" "surface.html#tfoot"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align, char, charoff, valign. <br><p><font size = 2>Content model: (tr)+</font>
(define (xhtml1:tfoot contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("align" ("left" "center" "right" "justify" "char") "#IMPLIED") ("char" "CDATA" "#IMPLIED") ("charoff" "CDATA" "#IMPLIED") ("valign" ("top" "middle" "bottom" "baseline") "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "tfoot")) (if validate-html? (validate-contents! contents (one-or-more "tr") "tfoot")) (if (and #f check-element-prohibitions?) (validate-contents! contents tfoot-extra-checker "tfoot")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "tfoot" " - " "We embed 'false' in a double tag"))) (internal-ast-node "tfoot" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>tbody</b> double tag element . <br>
;; .parameter contents The contents of the tbody element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "tbody" "surface.html#tbody"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align, char, charoff, valign. <br><p><font size = 2>Content model: (tr)+</font>
(define (xhtml1:tbody contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("align" ("left" "center" "right" "justify" "char") "#IMPLIED") ("char" "CDATA" "#IMPLIED") ("charoff" "CDATA" "#IMPLIED") ("valign" ("top" "middle" "bottom" "baseline") "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "tbody")) (if validate-html? (validate-contents! contents (one-or-more "tr") "tbody")) (if (and #f check-element-prohibitions?) (validate-contents! contents tbody-extra-checker "tbody")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "tbody" " - " "We embed 'false' in a double tag"))) (internal-ast-node "tbody" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>colgroup</b> double tag element . <br>
;; .parameter contents The contents of the colgroup element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "colgroup" "surface.html#colgroup"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, span, width, align, char, charoff, valign. <br><p><font size = 2>Content model: (col)*</font>
(define (xhtml1:colgroup contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("span" "CDATA" ""1"") ("width" "CDATA" "#IMPLIED") ("align" ("left" "center" "right" "justify" "char") "#IMPLIED") ("char" "CDATA" "#IMPLIED") ("charoff" "CDATA" "#IMPLIED") ("valign" ("top" "middle" "bottom" "baseline") "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "colgroup")) (if validate-html? (validate-contents! contents (zero-or-more "col") "colgroup")) (if (and #f check-element-prohibitions?) (validate-contents! contents colgroup-extra-checker "colgroup")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "colgroup" " - " "We embed 'false' in a double tag"))) (internal-ast-node "colgroup" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>col</b> single tag element . <br>
;; .parameter attributes HTML and CSS attribute value pairs on Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "col" "surface.html#col"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, span, width, align, char, charoff, valign. <br>
(define (xhtml1:col  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("span" "CDATA" ""1"") ("width" "CDATA" "#IMPLIED") ("align" ("left" "center" "right" "justify" "char") "#IMPLIED") ("char" "CDATA" "#IMPLIED") ("charoff" "CDATA" "#IMPLIED") ("valign" ("top" "middle" "bottom" "baseline") "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "col")) (terminal-ast-node "col" attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>tr</b> double tag element . <br>
;; .parameter contents The contents of the tr element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "tr" "surface.html#tr"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align, char, charoff, valign. <br><p><font size = 2>Content model: (th | td)+</font>
(define (xhtml1:tr contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("align" ("left" "center" "right" "justify" "char") "#IMPLIED") ("char" "CDATA" "#IMPLIED") ("charoff" "CDATA" "#IMPLIED") ("valign" ("top" "middle" "bottom" "baseline") "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "tr")) (if validate-html? (validate-contents! contents (one-or-more "th" "td") "tr")) (if (and #f check-element-prohibitions?) (validate-contents! contents tr-extra-checker "tr")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "tr" " - " "We embed 'false' in a double tag"))) (internal-ast-node "tr" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>th</b> double tag element . <br>
;; .parameter contents The contents of the th element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "th" "surface.html#th"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, abbr, axis, headers, scope, rowspan, colspan, align, char, charoff, valign. <br><p><font size = 2>Content model: (#pcdata | p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:th contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("abbr" "CDATA" "#IMPLIED") ("axis" "CDATA" "#IMPLIED") ("headers" "IDREFS" "#IMPLIED") ("scope" ("row" "col" "rowgroup" "colgroup") "#IMPLIED") ("rowspan" "CDATA" ""1"") ("colspan" "CDATA" ""1"") ("align" ("left" "center" "right" "justify" "char") "#IMPLIED") ("char" "CDATA" "#IMPLIED") ("charoff" "CDATA" "#IMPLIED") ("valign" ("top" "middle" "bottom" "baseline") "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "th")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "p" "h1" "h2" "h3" "h4" "h5" "h6" "div" "ul" "ol" "dl" "pre" "hr" "blockquote" "address" "fieldset" "table" "form" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "th")) (if (and #f check-element-prohibitions?) (validate-contents! contents th-extra-checker "th")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "th" " - " "We embed 'false' in a double tag"))) (internal-ast-node "th" contents attributes)))

;; The LAML mirror of the XHMTL1.0 (strict) <b>td</b> double tag element . <br>
;; .parameter contents The contents of the td element - a list of content elements (strings, sub-elements, space suppress, or lists of these).
;; .parameter attributes HTML and CSS attribute value pairs on  Lisp property list format. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .returns An instance of an abstract syntaxt tree.
;; .reference "similar surface form" "td" "surface.html#td"
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, xml:lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, abbr, axis, headers, scope, rowspan, colspan, align, char, charoff, valign. <br><p><font size = 2>Content model: (#pcdata | p | h1 | h2 | h3 | h4 | h5 | h6 | div | ul | ol | dl | pre | hr | blockquote | address | fieldset | table | form | a | br | span | bdo | object | img | map | tt | i | b | big | small | em | strong | dfn | code | q | sub | sup | samp | kbd | var | cite | abbr | acronym | input | select | textarea | label | button | ins | del | script | noscript)*</font>
(define (xhtml1:td contents  . attributes) (let ((attributes-of-elements (quote (("id" "ID" "#IMPLIED") ("class" "CDATA" "#IMPLIED") ("style" "CDATA" "#IMPLIED") ("title" "CDATA" "#IMPLIED") ("lang" "CDATA" "#IMPLIED") ("xml:lang" "CDATA" "#IMPLIED") ("dir" ("ltr" "rtl") "#IMPLIED") ("onclick" "CDATA" "#IMPLIED") ("ondblclick" "CDATA" "#IMPLIED") ("onmousedown" "CDATA" "#IMPLIED") ("onmouseup" "CDATA" "#IMPLIED") ("onmouseover" "CDATA" "#IMPLIED") ("onmousemove" "CDATA" "#IMPLIED") ("onmouseout" "CDATA" "#IMPLIED") ("onkeypress" "CDATA" "#IMPLIED") ("onkeydown" "CDATA" "#IMPLIED") ("onkeyup" "CDATA" "#IMPLIED") ("abbr" "CDATA" "#IMPLIED") ("axis" "CDATA" "#IMPLIED") ("headers" "IDREFS" "#IMPLIED") ("scope" ("row" "col" "rowgroup" "colgroup") "#IMPLIED") ("rowspan" "CDATA" ""1"") ("colspan" "CDATA" ""1"") ("align" ("left" "center" "right" "justify" "char") "#IMPLIED") ("char" "CDATA" "#IMPLIED") ("charoff" "CDATA" "#IMPLIED") ("valign" ("top" "middle" "bottom" "baseline") "#IMPLIED")))) (req-n 0)) (if check-html-attributes? (check-attributes! attributes attributes-of-elements req-n "td")) (if validate-html? (validate-contents! contents (zero-or-more "#pcdata" "p" "h1" "h2" "h3" "h4" "h5" "h6" "div" "ul" "ol" "dl" "pre" "hr" "blockquote" "address" "fieldset" "table" "form" "a" "br" "span" "bdo" "object" "img" "map" "tt" "i" "b" "big" "small" "em" "strong" "dfn" "code" "q" "sub" "sup" "samp" "kbd" "var" "cite" "abbr" "acronym" "input" "select" "textarea" "label" "button" "ins" "del" "script" "noscript") "td")) (if (and #f check-element-prohibitions?) (validate-contents! contents td-extra-checker "td")) (if (not contents) (display-warning (string-append "Cannot generate a single tag for " "td" " - " "We embed 'false' in a double tag"))) (internal-ast-node "td" contents attributes)))

